/*   
	procedure:     	FillRecoveryAccount.prc
     	written by:    	Craig Deane
     	date written:  	July 2020
     	database:      	welcoll
     	function:      	This fills the RecoveryAccount table with claim data
     	modified by:   	Craig Deane 10/6/2020
     	changes:	Updated to reflect new layout
     	modified by:   	Craig Deane 10/7/2020
     	changes: 	Added Loan processing
     	modified by:   	Craig Deane 12/11/2020
     	changes: 	Added the LegacyAccountNumberIdentifierFunction that will return the debt_number when a debt does not have a claim_number
     	modified by:   	Craig Deane 2/2021
     	changes: 	Modified to use the DebtList table to filter results	
     	modified by:   	Craig Deane 3/10/2021 FSD 1.6
     	changes:       	Added the "CDS Case Indicator" field	
     	modified by:   	Craig Deane 3/17/2021
     	changes:       	Modified to use the new LegacyAccountNumberIdentifierFunction table valued function
     	modified by:   	Craig Deane 3/25/2021 FSD 1.7
     	changes:       	Renamed CDSCaseIndicator to NonCalWINCaseIndicator
     	modified by:   	Craig Deane 4/28/2021 FSD 1.7
     	changes: 	Modified the Organization Name processing. Fixed the Reason Code processing
     	modified by:   	Craig Deane 6/10/2021 FSD 1.7
     	changes: 	Added the county code as a default for the Staff ID	
    	modified by:   	Craig Deane 7/28/2021 FSD 1.8
     	changes: 	Modified the Staff ID processing to use the value from the VACSWorkers table when using the Vehicle option
    	modified by:   	Craig Deane 9/30/2021 Version 2.0
     	changes: 	Added the VACSWorkers table processing for Staff ID to the other options
    	modified by:   	Craig Deane1/11/2022 Version 2.1
     	changes: 	Allowed negative amounts for Current Balance
    	modified by:   	Craig Deane 4/5/2022 Version 2.2
     	changes: 	Added Notification Date
    	modified by:   	Craig Deane 1/18/2023 Version 2.4
     	changes: 	Changed Status Date from max status_date in debt_status_history to date_debt_status
*/

use welcoll
go

IF EXISTS(SELECT 1
          FROM   INFORMATION_SCHEMA.ROUTINES
          WHERE  ROUTINE_NAME = 'FillRecoveryAccount'
                 AND SPECIFIC_SCHEMA = 'dbo')
  BEGIN
      DROP PROCEDURE dbo.FillRecoveryAccount
  END
go

create procedure dbo.FillRecoveryAccount
as

declare 	@serial_type_ind	char(1),
		@staffIDIND 		integer,
		@county_code		char(2),
		@notification_date_use 	integer,
		@notification_date_offset	integer

select @serial_type_ind = serial_type
  from calwin_control
 where calwin_key = 'C'

select @staffIDIND = staff_id_ind,
	@county_code = county_code,
	@notification_date_use 	= notification_date_use,
	@notification_date_offset = notification_date_offset
  from CalSAWSSettings
 where key_value = 1

delete RecoveryAccount 

insert RecoveryAccount 
select  "Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,

	"Case Number" = (select case when @serial_type_ind = 'V' then substring(debt.reference_number, 5, 7) else
					substring(debt.reference_number, 3, 7) 	end),
									
	"Organization Name" = Case When IsNull(provider_number, '') <> '' or IsNull(debtor1_name_mid_init, '') = '*' Then debtor1_name_last End,
										
	"Organization ID" = provider_number,
									
	"Priority Number" = (select priority_number
				from PriorityNumber
				Where debt_number = debt.debt_number),
								
	"Program Code" = (select calsaws_code		
		from CalSAWSProgramCodeMap
		where CalSAWSProgramCodeMap.vacs_code = debt.type_code),
			
	"Type Code" = 'RE',

	"Expire Date" = lomeli_end_date,

	"Discovery Date" = date_of_discovery,

	"Staff ID" = 	Case 	When @staffIDIND = 1 Then 
					Case 	When IsNull((select CalWINUserID
							from VACSWorkers, caseworker
							where case_info.worker_number = caseworker.worker_number and
								caseworker.worker_id = VACSWorker), '') = '' Then @county_code
						else
							(select CalWINUserID
							from VACSWorkers, caseworker
							where case_info.worker_number = caseworker.worker_number and
								caseworker.worker_id = VACSWorker) 
					End
				When @staffIDIND = 2 Then 
					Case 	When IsNull((select CalWINUserID
							from VACSWorkers, debtor_financial_information
							where debtor_id = debt.debtor_id and
							debtor_number = 1 and 
							vehicle_year_make_model = VACSWorker), '') = '' Then @county_code
						else
							(select CalWINUserID
							from VACSWorkers, debtor_financial_information
							where debtor_id = debt.debtor_id and
							debtor_number = 1 and 
							vehicle_year_make_model = VACSWorker) 
					End
				Else 
					Case 	When IsNull((select CalWINUserID
							from VACSWorkers
							where VACSWorker = worker_id), '') = '' Then @county_code
						else 
							(select CalWINUserID
							from VACSWorkers
							where VACSWorker = worker_id)
						
					End
			End,		
	"Status Code" = (select calsaws_code		
				from CalSAWSRecoveryAccountStatusMap
				where CalSAWSRecoveryAccountStatusMap.vacs_code = debt.debt_status),

	"Status Reason Code" = Case When (debtor1_intercept_submitted= 'Y' or debtor2_intercept_submitted = 'Y') and
					(select calsaws_code		
					from CalSAWSRecoveryAccountStatusReasonMap
					where CalSAWSRecoveryAccountStatusReasonMap.vacs_code = debt.debt_status) in ('AC', 'SU') Then  'TI' 
				Else (select calsaws_code		
					from CalSAWSRecoveryAccountStatusReasonMap
					where CalSAWSRecoveryAccountStatusReasonMap.vacs_code = debt.debt_status) End,

	"Reason Code" = Case When IsNull((select calsaws_code	
		from CalSAWSRecoveryAccountReasonMap
		where CalSAWSRecoveryAccountReasonMap.vacs_code = debt.debt_reason_code), '') = '' Then 'OH' 
		Else (select calsaws_code	
		from CalSAWSRecoveryAccountReasonMap
		where CalSAWSRecoveryAccountReasonMap.vacs_code = debt.debt_reason_code) End,

	"Status Date" = date_debt_status,

	"Investigation Code" = 'AN',

	"Current Balance" = balance_amount,

	"Cause Code" = Case When type_code = 'FOO' and
				debt_type_code = 'ADM' and
				date_entered < '20000301' 
				Then 'AP'
				Else 
					(select calsaws_code		
					from CalSAWSRecoveryAccountCauseMap
					where CalSAWSRecoveryAccountCauseMap.debt_type_code = debt.debt_type_code and
						CalSAWSRecoveryAccountCauseMap.type_code = debt.type_code) 
				End,

	"Cause Date" = date_entered,

	"Final demand Notice Date" = '12/01/9999',

	"Non-CalWIN Case Indicator" = Case When Not Exists (select claim_number from cw_claim_number where cw_claim_number.debt_number = debt.debt_number)
					Then 'Y' Else 'N' End,

	"Notification Date" = Case When @notification_date_use = 1 Then DATEADD(day, @notification_date_offset, date_of_discovery) 
				   When @notification_date_use = 2 Then DATEADD(day, @notification_date_offset, demand_letter_date1) 
				   Else DATEADD(day, @notification_date_offset, date_entered) 
			      End
								
		

from debt
JOIN debtor ON debtor.debtor_id = debt.debtor_id
JOIN case_info ON case_info.reference_number = debt.reference_number
JOIN DebtList ON DebtList.debt_number = debt.debt_number
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number
         
go

grant execute on FillRecoveryAccount to public
go

/*   	
	procedure:	FillRecoveryAccountResponsibleParty.prc
	written by:    	Craig Deane
     	date written:  	September 2020
     	database:      	welcoll
     	function:      	This fills the RecoveryAccountResponsibleParty table with debtor data
     	modified by:  	Craig Deane 12/3/2020 FSD 1.4
     	changes:	Added support for PhysicalAddressEffectiveDate, MailingAddressEffectiveDate, Language, WrittenLanguage, and PersonNumberIdentifier
     	modified by:   	Craig Deane 2/2021
     	changes:	Modified to use the DebtList table to filter results
     	modified by:   	Craig Deane 3/18/2021
     	changes:       	Modified to use the new LegacyAccountNumberIdentifierFunction table valued function	
     	modified by:   	Craig Deane 4/28/2021 FSD 1.7
     	changes:	Modified the processing for Organization Name and Debtor Type. Fixed the Language processing
     	modified by:   	Craig Deane 6/10/2021 FSD 1.7
     	changes:	Made it use the Private Mail Box or Care of Address when the Street Address is blank	
    	modified by:   	Craig Deane 9/30/2021 Version 2.0
     	changes:	Changed the processing for Person Identifier and moved CIN to the end of the record
   	modified by:   	Craig Deane 10/21/2021 Version 2.0.1
     	changes:	Changed processing for Organizations 
   	modified by:   	Craig Deane 1/11/2022 Version 2.1
     	changes:	Fixed a bug where it was possible for an Organization to have a name suffix. Added support for Payee and Recipient for the File #8 process
  	modified by:   	Craig Deane 3/2/2023 Version 2.5
     	changes:	Added RecordType
*/

use welcoll
go

IF EXISTS(SELECT 1
          FROM   INFORMATION_SCHEMA.ROUTINES
          WHERE  ROUTINE_NAME = 'FillRecoveryAccountResponsibleParty'
                 AND SPECIFIC_SCHEMA = 'dbo')
  BEGIN
      DROP PROCEDURE dbo.FillRecoveryAccountResponsibleParty
  END
go

create procedure dbo.FillRecoveryAccountResponsibleParty
as

declare 	@serial_type_ind	char(1),
	  	@program_status_ind char(1)

select @serial_type_ind = serial_type
  from calwin_control
 where calwin_key = 'C'

select @program_status_ind = IsNull(program_status_ind, 'N')
  from tax_intercept_control
  where tax_intercept_key = 'I'


delete RecoveryAccountResponsibleParty

insert RecoveryAccountResponsibleParty
/* Responsible Party from Debtor 1 */
select 	"Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,

	"Case Number" = (select case when @serial_type_ind = 'V' then substring(debt.reference_number, 5, 7) else
					substring(debt.reference_number, 3, 7) 	end),

	"Person Identifier" = Case When IsNull(debtor1_name_mid_init, '') <> '*' Then '1' + Replicate('0', 8 - Len(Convert(varchar(9), debtor.debtor_id))) + Convert(varchar(9), debtor.debtor_id) End,

	"Organization ID" = Case When IsNull(debtor1_name_mid_init, '') = '*' Then provider_number End,

	"Adjustment Indicator" = Case When @program_status_ind = 'Y' and IsNull(debt.program_status, case_status) = 'A' or
						@program_status_ind = 'N' and IsNull(case_status, debt.program_status) = 'A' Then 'Y' 
					Else 'N' End,

	"Bill Indicator" = Case When statement_ind = 'Y' and debtor1_statement_ind = 'Y' Then 'Y' Else 'N' End,

	"Tax Intercept Indicator" = IsNull(debtor1_ftb_intercept_ind, 'N'),

	"Responsible Party Status Date" = date_entered,

	"Delinquent Date" = delinquency_date, 

	"Debtor Type" = Case When IsNull(debtor1_name_mid_init, '') = '*' Then 'C' Else 'I' End,

	"Responsible Party First Name" = Case When IsNull(debtor1_name_mid_init, '') <> '*' Then debtor1_name_first End,

	"Responsible Party Middle Name" = Case When IsNull(debtor1_name_mid_init, '') <> '*' Then debtor1_name_mid_init End,

	"Responsible Party Last Name" = Case When IsNull(debtor1_name_mid_init, '') <> '*' Then 
					(select last_name from dbo.NameSuffixFunction(debtor1_name_last)) End, 

	"Responsible Party Suffix" = Case When IsNull(debtor1_name_mid_init, '') <> '*' Then 
					(select suffix_name from dbo.NameSuffixFunction(debtor1_name_last)) End, 

	"Responsible Party Status" = 'AC',

	"Organization Name" = Case When IsNull(debtor1_name_mid_init, '') = '*' Then debtor1_name_last End,

	"AKA First Name" = first_name,

	"AKA Middle Name" = '',

	"AKA Last Name" = (select last_name from dbo.NameSuffixFunction(last_name)),

	"AKA Suffix" = (select suffix_name from dbo.NameSuffixFunction(last_name)),

	"Coresponsible Flag" = Case When IsNull(debtor2_name_last, '') != '' Then 'Y' Else 'N' End,

	"Physical Address - Effective Date" = null,

	"Physical Address - Line 1 Address" = '',

	"Physical  Address - Line 2 Address" = '',

	"Physical  Address - City Name" = '',

	"Physical  Address- State Code" = '',

	"Physical  Address - Zip Code" = '',

	"Mailing Address - Effective Date" = dbo.AddressEffectiveDateFunction(debtor.debtor_id),

	"Mailing Address- Line 1 Address" = Case When IsNull(debtor1_street_address, '') <> '' Then (select address_line1 from AddressFunction(debtor1_street_address)) Else
						Case When IsNull(debtor1_private_mailbox, '') <> '' Then debtor1_private_mailbox Else
							Case When IsNull(debtor1_care_of_address, '') <> '' Then debtor1_care_of_address End 
						End 
					    End,

	"Mailing Address- Line 2 Address" = Case When IsNull(debtor1_street_address, '') <> '' Then (select address_line2 from AddressFunction(debtor1_street_address)) End,

	"Mailing Address - City Name" = debtor1_city,

	"Mailing Address- State Code" = debtor1_state,

	"Mailing Address - Zip Code" =  debtor1_zip,

	"Phone Number - Area Code" = substring(debtor1_phone, 1, 3),

	"Phone Number" = substring(debtor1_phone, 4, 7),

	"Phone Extension Number" = '',

	"Responsible Party Date of Birth" = debtor1_dob,

	"Responsible Party SSN" = debtor1_ssn,

	"Responsible Party Driver License Number" = debtor1_drivers_license,

	"Language" = Case When IsNull((select calsaws_code		
			from CalSAWSLanguageCodeMap
			where CalSAWSLanguageCodeMap.vacs_code = debtor.primary_language_code), '') = '' Then '03'
			Else (select calsaws_code		
			from CalSAWSLanguageCodeMap
			where CalSAWSLanguageCodeMap.vacs_code = debtor.primary_language_code) End,

	"Written Language" = '',

	"Person Number Identifier" = '01',

	"CIN" = cin1,

	RecordType = 'N'

from debt
INNER JOIN debtor ON debt.debtor_id = debtor.debtor_id
INNER JOIN DebtList ON debt.debt_number = DebtList.debt_number
INNER JOIN case_info ON case_info.reference_number = debt.reference_number
LEFT OUTER JOIN alias_names ON debt.debtor_id = alias_names.debtor_id
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number

where (alias_sequence_number = (select max(alias_sequence_number)
				from alias_names
				where debtor_id = debt.debtor_id) or 
	alias_sequence_number is null) and
	file8_process_indicator != 'Y'


union

/* Responsible Party from Debtor 2 */
select "Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,

	"Case Number" = (select case when @serial_type_ind = 'V' then substring(debt.serial_number, 3, 7) else
					substring(debt.serial_number, 1, 7) 	end),

	"Person Identifier" = '2' + Replicate('0', 8 - Len(Convert(varchar(9), debtor.debtor_id))) + Convert(varchar(9), debtor.debtor_id),

	"Organization ID" = '',

	"Adjustment Indicator" = Case When @program_status_ind = 'Y' and IsNull(debt.program_status, case_status) = 'A' or
						@program_status_ind = 'N' and IsNull(case_status, debt.program_status) = 'A' Then 'Y' 
					Else 'N' End,	

	"Bill Indicator" = Case When statement_ind = 'Y' and debtor2_statement_ind = 'Y' Then 'Y' Else 'N' End,

	"Tax Intercept Indicator" = IsNull(debtor2_ftb_intercept_ind, 'N'),

	"Responsible Party Status Date" = date_entered,

	"Delinquent Date" = delinquency_date, 

	"Debtor Type" = 'I',

	"Responsible Party First Name" = debtor2_name_first,

	"Responsible Party Middle Name" = debtor2_name_mid_init,

	"Responsible Party Last Name" = (select last_name from dbo.NameSuffixFunction(debtor2_name_last)),

	"Responsible Party Suffix" = (select suffix_name from dbo.NameSuffixFunction(debtor2_name_last)),

	"Responsible Party Status" = 'AC',

	"Organization Name" = '',

	"AKA First Name" = first_name,

	"AKA Middle Name" = '',

	"AKA Last Name" = (select last_name from dbo.NameSuffixFunction(last_name)),

	"AKA Suffix" = (select suffix_name from dbo.NameSuffixFunction(last_name)),

	"Coresponsible Flag" = 'Y',

	"Physical Address - Effective Date" = null,

	"Physical Address- Line 1 Address" = '',

	"Physical Address- Line 2 Address" = '',

	"Physical Address - City Name" = '',

	"Physical Address- State Code" = '',

	"Physical Address - Zip Code" = '',

	"Mailing Address - Effective Date" = dbo.AddressEffectiveDateFunction(dbo.debtor.debtor_id),

	"Mailing Address- Line 1 Address" = Case When IsNull(debtor2_street_address, '') + IsNull(debtor2_care_of_address, '') + IsNull(debtor2_private_mailbox, '') = '' Then 
					         Case When IsNull(debtor1_street_address, '') <> '' Then (select address_line1 from AddressFunction(debtor1_street_address)) Else
						     Case When IsNull(debtor1_private_mailbox, '') <> '' Then debtor1_private_mailbox Else
						         Case When IsNull(debtor1_care_of_address, '') <> '' Then debtor1_care_of_address End 
						     End 
					         End
						 Else
						 Case When IsNull(debtor2_street_address, '') <> '' Then (select address_line1 from AddressFunction(debtor2_street_address)) Else
						     Case When IsNull(debtor2_private_mailbox, '') <> '' Then debtor2_private_mailbox Else
						     	Case When IsNull(debtor2_care_of_address, '') <> '' Then debtor2_care_of_address End 
						     End 
					         End
					     End,

	"Mailing Address- Line 2 Address" = Case When IsNull(debtor2_street_address, '') + IsNull(debtor2_care_of_address, '') + IsNull(debtor2_private_mailbox, '') = '' Then
						(select address_line2 from AddressFunction(debtor2_street_address))
						Else (select address_line2 from AddressFunction(debtor1_street_address))
					     End,

	"Mailing Address - City Name" = Case When IsNull(debtor2_street_address, '') + IsNull(debtor2_care_of_address, '') + IsNull(debtor2_private_mailbox, '') = '' Then debtor1_city Else debtor2_city End,

	"Mailing Address- State Code" = Case When IsNull(debtor2_street_address, '') + IsNull(debtor2_care_of_address, '') + IsNull(debtor2_private_mailbox, '') = '' Then debtor1_state Else debtor2_state End,

	"Mailing Address - Zip Code" =  Case When IsNull(debtor2_street_address, '') + IsNull(debtor2_care_of_address, '') + IsNull(debtor2_private_mailbox, '') = '' Then debtor1_zip Else debtor2_zip End,

	"Phone Number - Area Code" = substring(debtor2_phone, 1, 3),

	"Phone Number" = substring(debtor2_phone, 4, 7),

	"Phone Extension Number" = '',

	"Responsible Party Date of Birth" = debtor2_dob,

	"Responsible Party SSN" = debtor2_ssn,

	"Responsible Party Driver License Number" = debtor2_drivers_license,

	"Language" = Case When IsNull((select calsaws_code		
			from CalSAWSLanguageCodeMap
			where CalSAWSLanguageCodeMap.vacs_code = debtor.primary_language_code), '') = '' Then '03'
			Else (select calsaws_code		
			from CalSAWSLanguageCodeMap
			where CalSAWSLanguageCodeMap.vacs_code = debtor.primary_language_code) End,

	"Written Language" = '',

	"Person Number Identifier" = '02',

	"CIN" = cin2,

	RecordType = 'N'
					
from debt
INNER JOIN debtor ON debt.debtor_id = debtor.debtor_id
INNER JOIN DebtList ON debt.debt_number = DebtList.debt_number
INNER JOIN case_info ON case_info.reference_number = debt.reference_number
LEFT OUTER JOIN alias_names ON debt.debtor_id = alias_names.debtor_id
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number
where IsNull(debtor2_name_last, '') != '' and
	(alias_sequence_number = (select max(alias_sequence_number)
				from alias_names
				where debtor_id = debt.debtor_id) or 
				alias_sequence_number is null)  and
	file8_process_indicator != 'Y'

union

/* File#8 Recipient */
select 	"Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,

	"Case Number" = (select case when @serial_type_ind = 'V' then substring(debt.reference_number, 5, 7) else
					substring(debt.reference_number, 3, 7) 	end),

	"Person Identifier" = '3' + Replicate('0', 8 - Len(Convert(varchar(9), debtor.debtor_id))) + Convert(varchar(9), debtor.debtor_id),

	"Organization ID" = '',

	"Adjustment Indicator" = Case When @program_status_ind = 'Y' and IsNull(debt.program_status, case_status) = 'A' or
						@program_status_ind = 'N' and IsNull(case_status, debt.program_status) = 'A' Then 'Y' 
					Else 'N' End,

	"Bill Indicator" = Case When statement_ind = 'Y' and debtor1_statement_ind = 'Y' Then 'Y' Else 'N' End,

	"Tax Intercept Indicator" = IsNull(debtor1_ftb_intercept_ind, 'N'),

	"Responsible Party Status Date" = date_entered,

	"Delinquent Date" = delinquency_date, 

	"Debtor Type" = 'I',

	"Responsible Party First Name" = name_first,

	"Responsible Party Middle Name" = name_mid_init,

	"Responsible Party Last Name" = (select last_name from dbo.NameSuffixFunction(name_last)),

	"Responsible Party Suffix" = (select suffix_name from dbo.NameSuffixFunction(name_last)), 

	"Responsible Party Status" = 'AC',

	"Organization Name" = '',

	"AKA First Name" = '',

	"AKA Middle Name" = '',

	"AKA Last Name" = '',

	"AKA Suffix" = '',

	"Coresponsible Flag" = 'N',

	"Physical Address - Effective Date" = null,

	"Physical Address - Line 1 Address" = '',

	"Physical  Address - Line 2 Address" = '',

	"Physical  Address - City Name" = '',

	"Physical  Address- State Code" = '',

	"Physical  Address - Zip Code" = '',

	"Mailing Address - Effective Date" = '',

	"Mailing Address- Line 1 Address" = Case When IsNull(street_address, '') <> '' Then (select address_line1 from AddressFunction(street_address)) Else
						Case When IsNull(private_mailbox, '') <> '' Then private_mailbox Else
							Case When IsNull(care_of_address, '') <> '' Then care_of_address End 
						End 
					    End,

	"Mailing Address- Line 2 Address" = Case When IsNull(street_address, '') <> '' Then (select address_line2 from AddressFunction(street_address)) End,

	"Mailing Address - City Name" = city,

	"Mailing Address- State Code" = state,

	"Mailing Address - Zip Code" =  zip,

	"Phone Number - Area Code" = '',

	"Phone Number" = '',

	"Phone Extension Number" = '',

	"Responsible Party Date of Birth" = '',

	"Responsible Party SSN" = '',

	"Responsible Party Driver License Number" = '',

	"Language" = Case When IsNull((select calsaws_code		
			from CalSAWSLanguageCodeMap
			where CalSAWSLanguageCodeMap.vacs_code = case_info.primary_language_code), '') = '' Then '03'
			Else (select calsaws_code		
			from CalSAWSLanguageCodeMap
			where CalSAWSLanguageCodeMap.vacs_code = case_info.primary_language_code) End,

	"Written Language" = '',

	"Person Number Identifier" = '01',

	"CIN" = '',

	RecordType = 'R'

from debt
INNER JOIN debtor ON debt.debtor_id = debtor.debtor_id
INNER JOIN DebtList ON debt.debt_number = DebtList.debt_number
INNER JOIN case_info ON case_info.reference_number = debt.reference_number
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number

where file8_process_indicator = 'Y'

union

/* File#8 Payee */
select 	"Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,

	"Case Number" = (select case when @serial_type_ind = 'V' then substring(debt.reference_number, 5, 7) else
					substring(debt.reference_number, 3, 7) 	end),

	"Person Identifier" = '',

	"Organization ID" = '1' + Replicate('0', 8 - Len(Convert(varchar(9), debtor.debtor_id))) + Convert(varchar(9), debtor.debtor_id),

	"Adjustment Indicator" = Case When @program_status_ind = 'Y' and IsNull(debt.program_status, case_status) = 'A' or
						@program_status_ind = 'N' and IsNull(case_status, debt.program_status) = 'A' Then 'Y' 
					Else 'N' End,

	"Bill Indicator" = Case When statement_ind = 'Y' and debtor1_statement_ind = 'Y' Then 'Y' Else 'N' End,

	"Tax Intercept Indicator" = IsNull(debtor1_ftb_intercept_ind, 'N'),

	"Responsible Party Status Date" = date_entered,

	"Delinquent Date" = delinquency_date, 

	"Debtor Type" = 'I',

	"Responsible Party First Name" = '',

	"Responsible Party Middle Name" = '',

	"Responsible Party Last Name" =	'', 

	"Responsible Party Suffix" = '',

	"Responsible Party Status" = 'AC',

	"Organization Name" = debtor1_name_first + ' ' + Case When IsNull(debtor1_name_mid_init, '') = '' Then debtor1_name_mid_init + ' ' Else '' End + (select last_name from dbo.NameSuffixFunction(debtor1_name_last)) + ' ' + (select suffix_name from dbo.NameSuffixFunction(debtor1_name_last)),

	"AKA First Name" = first_name,

	"AKA Middle Name" = '',

	"AKA Last Name" = (select last_name from dbo.NameSuffixFunction(last_name)),

	"AKA Suffix" = (select suffix_name from dbo.NameSuffixFunction(last_name)),

	"Coresponsible Flag" = Case When IsNull(debtor2_name_last, '') != '' Then 'Y' Else 'N' End,

	"Physical Address - Effective Date" = null,

	"Physical Address - Line 1 Address" = '',

	"Physical  Address - Line 2 Address" = '',

	"Physical  Address - City Name" = '',

	"Physical  Address- State Code" = '',

	"Physical  Address - Zip Code" = '',

	"Mailing Address - Effective Date" = dbo.AddressEffectiveDateFunction(debtor.debtor_id),

	"Mailing Address- Line 1 Address" = Case When IsNull(debtor1_street_address, '') <> '' Then (select address_line1 from AddressFunction(debtor1_street_address)) Else
						Case When IsNull(debtor1_private_mailbox, '') <> '' Then debtor1_private_mailbox Else
							Case When IsNull(debtor1_care_of_address, '') <> '' Then debtor1_care_of_address End 
						End 
					    End,

	"Mailing Address- Line 2 Address" = Case When IsNull(debtor1_street_address, '') <> '' Then (select address_line2 from AddressFunction(debtor1_street_address)) End,

	"Mailing Address - City Name" = debtor1_city,

	"Mailing Address- State Code" = debtor1_state,

	"Mailing Address - Zip Code" =  debtor1_zip,

	"Phone Number - Area Code" = substring(debtor1_phone, 1, 3),

	"Phone Number" = substring(debtor1_phone, 4, 7),

	"Phone Extension Number" = '',

	"Responsible Party Date of Birth" = debtor1_dob,

	"Responsible Party SSN" = debtor1_ssn,

	"Responsible Party Driver License Number" = debtor1_drivers_license,

	"Language" = Case When IsNull((select calsaws_code		
			from CalSAWSLanguageCodeMap
			where CalSAWSLanguageCodeMap.vacs_code = debtor.primary_language_code), '') = '' Then '03'
			Else (select calsaws_code		
			from CalSAWSLanguageCodeMap
			where CalSAWSLanguageCodeMap.vacs_code = debtor.primary_language_code) End,

	"Written Language" = '',

	"Person Number Identifier" = '01',

	"CIN" = cin1,

	RecordType = 'P'

from debt
INNER JOIN debtor ON debt.debtor_id = debtor.debtor_id
INNER JOIN DebtList ON debt.debt_number = DebtList.debt_number
INNER JOIN case_info ON case_info.reference_number = debt.reference_number
LEFT OUTER JOIN alias_names ON debt.debtor_id = alias_names.debtor_id
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number

where (alias_sequence_number = (select max(alias_sequence_number)
				from alias_names
				where debtor_id = debt.debtor_id) or 
	alias_sequence_number is null) and
	file8_process_indicator = 'Y'

update RecoveryAccountResponsibleParty
set PhysicalAddressEffectiveDate = MailingAddressEffectiveDate,
PhysicalAddressLine1Address = MailingAddressLine1Address,
PhysicalAddressLine2Address = MailingAddressLine2Address,
PhysicalAddressCityName = MailingAddressCityName,
PhysicalAddressStateCode = MailingAddressStateCode,
PhysicalAddressZipCode = MailingAddressZipCode,
WrittenLanguage = Language
            
go

grant execute on FillRecoveryAccountResponsibleParty to public
go

/*   	procedure:     	FillRecoveryAccountRepaymentTerm.prc
	written by:    	Craig Deane
     	date written:  	September 2020
     	database:      	welcoll
     	function:      	This fills the RecoveryAccountRepaymentTerm table with claim data
     	modified by:   	Craig Deane 2/2021
     	changes:	Modified to use the DebtList table to filter results
     	modified by:   	Craig Deane 3/17//2021
     	changes:       	Modified to use the new LegacyAccountNumberIdentifierFunction table valued function	
    	modified by:   	Craig Deane 9/30/2021 Version 2.0
     	changes:	Changed the processing for Person Identifier
   	modified by:   	Craig Deane 10/21/2021 Version 2.0.1
     	changes:	Changed processing for Organizations 
   	modified by:   	Craig Deane 4/5/2022 Version 2.2
     	changes:	Added Repayment Term Status and Repayment Term Incomplete Reason
*/

use welcoll
go

IF EXISTS(SELECT 1
          FROM   INFORMATION_SCHEMA.ROUTINES
          WHERE  ROUTINE_NAME = 'FillRecoveryAccountRepaymentTerm'
                 AND SPECIFIC_SCHEMA = 'dbo')
  BEGIN
      DROP PROCEDURE dbo.FillRecoveryAccountRepaymentTerm
  END
go

create procedure dbo.FillRecoveryAccountRepaymentTerm
as

declare 	@serial_type_ind	char(1)


select @serial_type_ind = serial_type
  from calwin_control
 where calwin_key = 'C'

delete RecoveryAccountRepaymentTerm

insert RecoveryAccountRepaymentTerm
select "Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,
	"Case Number" = (select case when @serial_type_ind = 'V' then substring(debt.reference_number, 5, 7) else
					substring(debt.reference_number, 3, 7) 	end),
	"Person Identifier" = Case When IsNull(debtor1_name_mid_init, '') <> '*' Then '1' + Replicate('0', 8 - Len(Convert(varchar(9), debtor.debtor_id))) + Convert(varchar(9), debtor.debtor_id) End,
	"Organization ID" = Case When IsNull(debtor1_name_mid_init, '') = '*' Then provider_number End,
	"Override Cause Indicator" = 'Y',
	"Repay Percent" = '000',
	"Repay Amount" = installment_amount,
	"Frequency Code" = 'MO',
	"Begin Date" = date_first_payment_due,
	"Type Code" = 'EP',
	"End Date" = date_last_payment_due,
	"Agreement Type" = '',
	"Entitlement Type" = '',
	"Repayment Term Status" = Case When balance_amount = 0 Then 'CL' Else 'AC' End,
	"Repayment Term Incomplete Reason" = ''
					
from debt
JOIN debtor ON debtor.debtor_id = debt.debtor_id
JOIN case_info ON case_info.reference_number = debt.reference_number
JOIN payment_plan ON payment_plan.plan_id = debt.plan_id
JOIN DebtList ON DebtList.debt_number = debt.debt_number
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number
             
go

grant execute on FillRecoveryAccountRepaymentTerm to public
go

/*   
	procedure:	FillRecoveryAccountOverpayment.prc
     	written by:    	Craig Deane
     	date written:  	September 2020
     	database:      	welcoll
     	function:      	This fills the Recovery Account Overpayment table with claim data
     	modified by:   	Craig Deane 2/2021
     	changes: 	Modified to use the DebtList table to filter results	
     	modified by:   	Craig Deane 3/18//2021
     	changes:       	Modified to use the new LegacyAccountNumberIdentifierFunction table valued function
     	modified by:   	Craig Deane 4/28/2021 FSD 1.7
     	changes:	Fixed the Aid Code processing
     	modified by:   	Craig Deane 6/10/2021 FSD 1.7 
     	changes:	Added the option for the Effective Date
     	modified by:   	Craig Deane 7/28/2021 FSD 1.8
     	changes:	Fixed a bug where additional charges were being added to the Amounts
*/

use welcoll
go

IF EXISTS(SELECT 1
          FROM   INFORMATION_SCHEMA.ROUTINES
          WHERE  ROUTINE_NAME = 'FillRecoveryAccountOverpayment'
                 AND SPECIFIC_SCHEMA = 'dbo')
  BEGIN
      DROP PROCEDURE dbo.FillRecoveryAccountOverpayment
  END
go

create procedure dbo.FillRecoveryAccountOverpayment
as

declare @transaction_date_ind	integer

select @transaction_date_ind = transaction_date_ind
from CalSAWSSettings
where key_value = 1

delete RecoveryAccountOverpayment

insert RecoveryAccountOverpayment
select "Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,

	"Overpayment Amount" = financial_detail.amount,

	"Effective Date" = Case When @transaction_date_ind = 0 
				Then transaction_control.date_created
				Else transaction_control.date_effective
			   End,	
									
	"Original Amount" = financial_detail.amount,		
							
	"Corrected Amount" = 0,		
						
	"Aid Code" = Case When IsNull((select calsaws_code		
		from CalSAWSAidCodeMap
		where CalSAWSAidCodeMap.vacs_code = SUBSTRING(debt.reference_number, 1, 2)), '') = '' Then SUBSTRING(debt.reference_number, 1, 2)
		Else (select calsaws_code		
		from CalSAWSAidCodeMap
		where CalSAWSAidCodeMap.vacs_code = SUBSTRING(debt.reference_number, 1, 2)) End

from debt
INNER JOIN financial_detail ON debt.debt_number = financial_detail.debt_number
INNER JOIN DebtList ON debt.debt_number = DebtList.debt_number
INNER JOIN transaction_control ON financial_detail.transaction_number = transaction_control.transaction_number
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number

where 	transaction_code = 'OVP' and
	charge_code = 'DEB'

go

grant execute on FillRecoveryAccountOverpayment to public
go

/*   
	procedure:     	FillRecoveryAccountTransaction.prc
     	written by:    	Craig Deane
     	date written:  	10/12/2020
     	database:      	welcoll
     	function:      	This fills the RecoveryAccountTransaction table with transaction data
     	modified by:   	Craig Deane 2/2021
     	changes:	Modified to use the DebtList table to filter results
     	modified by:   	Craig Deane 3/3/2021
     	changes:	Set the Backed Out Indicator to blank	
     	modified by:   	Craig Deane 3/18//2021
     	changes:       	Modified to use the new LegacyAccountNumberIdentifierFunction table valued function
     	modified by:   	Craig Deane 6/10/2021 FSD 1.7 
     	changes:	Added the option for the Effective Date
     	modified by:   	Craig Deane 7/28/2021 FSD 1.8
     	changes:	Changed the sign on the amount to conform to CalSAWS
     	modified by:   	Craig Deane 2/10/2022 Version 2.1.1
     	changes:	Prepended the transaction sequence number to the transaction number to make it unique
 */

use welcoll
go

IF EXISTS(SELECT 1
          FROM   INFORMATION_SCHEMA.ROUTINES
          WHERE  ROUTINE_NAME = 'FillRecoveryAccountTransaction'
                 AND SPECIFIC_SCHEMA = 'dbo')
  BEGIN
      DROP PROCEDURE dbo.FillRecoveryAccountTransaction
  END
go

create procedure dbo.FillRecoveryAccountTransaction
as

declare @transaction_date_ind	integer

select @transaction_date_ind = transaction_date_ind
from CalSAWSSettings
where key_value = 1

delete RecoveryAccountTransaction 

insert RecoveryAccountTransaction 
select "Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,

 	"Transaction Number Identifier" = Convert(varchar(3), financial_detail.transaction_sequence_number) +
				Replicate('0', 10 - Len(Convert(varchar(3), financial_detail.transaction_sequence_number)) - Len(Convert(varchar(9), 							financial_detail.transaction_number))) +
				Convert(varchar(9), financial_detail.transaction_number),
	"Transaction Amount" = - financial_detail.amount,
	"Transaction Type Code" = (select calsaws_code		
				from CalSAWSTransactionTypeMap
				where CalSAWSTransactionTypeMap.vacs_code = transaction_control.transaction_code),
	"Transaction Delivery Type Code" = 'SY',
	"Effective Date" = Case When @transaction_date_ind = 0 
				Then transaction_control.date_created
				Else transaction_control.date_effective
			   End,	
	"Posted Date" = transaction_control.date_created,
	"Backed Out Indicator" = '',
	"Posted Status Code" = 'PR'
					
					
from debt
JOIN financial_detail ON financial_detail.debt_number = debt.debt_number
JOIN transaction_control ON transaction_control.transaction_number = financial_detail.transaction_number
JOIN DebtList ON DebtList.debt_number = debt.debt_number
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number

where transaction_control.transaction_code <> 'OVP' and
	financial_detail.charge_code = 'DEB'
             
go

grant execute on FillRecoveryAccountTransaction to public
go

/*   
	procedure:     	FillRecoveryAccountTransactionDetail.prc
     	written by:    	Craig Deane
     	date written:  	10/13/2020
     	database:      	welcoll
     	function:      	This fills the RecoveryAccountTransactionDetail table with transaction data
     	modified by:   	Craig Deane 2/2021
     	changes: 	Modified to use the DebtList table to filter results	
     	modified by:   	Craig Deane 3/3/2021
     	changes:	Modified to use the CleanMemoFunction function
     	modified by:   	Craig Deane 3/18//2021
     	changes:       	Modified to use the new LegacyAccountNumberIdentifierFunction table valued function
     	modified by:   	Craig Deane 4/28/2021 FSD 1.7
     	changes:	Fixed the Transaction Description processing
     	modified by:   	Craig Deane 2/10/2022 Version 2.1.1
     	changes:	Prepended the transaction sequence number to the transaction number to make it unique
 */

use welcoll
go

IF EXISTS(SELECT 1
          FROM   INFORMATION_SCHEMA.ROUTINES
          WHERE  ROUTINE_NAME = 'FillRecoveryAccountTransactionDetail'
                 AND SPECIFIC_SCHEMA = 'dbo')
  BEGIN
      DROP PROCEDURE dbo.FillRecoveryAccountTransactionDetail
  END
go

create procedure dbo.FillRecoveryAccountTransactionDetail
as

delete RecoveryAccountTransactionDetail 

insert RecoveryAccountTransactionDetail 
select "Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,
 	"Transaction Number Identifier" = Convert(varchar(3), financial_detail.transaction_sequence_number) +
				Replicate('0', 10 - Len(Convert(varchar(3), financial_detail.transaction_sequence_number)) - Len(Convert(varchar(9), 							financial_detail.transaction_number))) +
				Convert(varchar(9), financial_detail.transaction_number),
	"Transaction Description" = substring(dbo.CleanMemoFunction(activity_code + 
				IsNull((select ' - ' + description from activity where activity_code = user_activity.activity_code), '') +  						IsNull((select ' - ' + logon_id from users where user_number = user_activity.user_number), '') + 
				IsNull( ' - ' + memo, '- No Memo Entered') + 
				IsNull(convert(varchar(max), memo_text), '')), 1, 2000)
					
from financial_detail
JOIN transaction_control ON financial_detail.transaction_number = transaction_control.transaction_number
JOIN debt_user_activity ON financial_detail.debt_number = debt_user_activity.debt_number
JOIN user_activity ON debt_user_activity.activity_number = user_activity.activity_number
JOIN DebtList ON DebtList.debt_number = financial_detail.debt_number
JOIN LegacyAccountNumberIdentifierFunction() ON financial_detail.debt_number = LegacyAccountNumberIdentifierFunction.debt_number

where  	transaction_control.date_created = user_activity.date_of_activity and
	transaction_control.transaction_code <> 'OVP' and
	financial_detail.charge_code = 'DEB'
             
go

grant execute on FillRecoveryAccountTransactionDetail to public
go

/*   	procedure:	FillRecoveryAccountCaseNotes.prc
    	written by:    	Craig Deane
     	date written:  	10/13/2020
     	database:      	welcoll
     	function:      	This fills the FillRecoveryAccountCaseNotes table with Activity memo data
     	modified by:   	Craig Deane 2/2021
     	changes: 	Modified to use the DebtList table to filter results
     	modified by:   	Craig Deane 3/3/2021
     	changes:	Modified to use the CleanMemoFunction function	
     	modified by:   	Craig Deane 3/18//2021
     	changes:       	Modified to use the new LegacyAccountNumberIdentifierFunction table valued function
     	modified by:   	Craig Deane 4/28/2021 FSD 1.7
     	changes:	Fixed the Note Description processing. Added unmapped Aid Code support
     	modified by:   	Craig Deane 6/8/2022 FSD 2.2
	changes:	Modified to split the memo into 2000 character chunks	
     	modified by:   	Craig Deane  FSD 2.2
	changes:	Fixed a bug where it was testing for number of characters rather than bytes
			Fixed a bug where additional record chunks had the same DateNoteEntered
     	modified by:   	Craig Deane  12/6/2022 FSD 2.3
	changes:	Made the record length a setting controlled by the user
     	modified by:   	Craig Deane  4/17/2023 FSD 2.5 Version 2.5.1
	changes:	Added Alerts
     	modified by:   	Craig Deane  4/18/2023 FSD 2.6 Version 2.6
	changes:	Added the RemoveNonASCII function
 */

use welcoll
go

IF EXISTS(SELECT 1
          FROM   INFORMATION_SCHEMA.ROUTINES
          WHERE  ROUTINE_NAME = 'FillRecoveryAccountCaseNotes'
                 AND SPECIFIC_SCHEMA = 'dbo')
  BEGIN
      DROP PROCEDURE dbo.FillRecoveryAccountCaseNotes
  END
go

if exists (select * from tempdb..sysobjects where name like '#RecoveryAccountCaseNotes%')
	drop table #RecoveryAccountCaseNotes
go


create procedure dbo.FillRecoveryAccountCaseNotes
as

declare @max_memo_length	FLOAT(1),
	@memo_count		integer,
	@index			integer,
	@record_length 		integer,
	@delete_special_chars_file7	char(1),
	@alerts_file7		char(1)

create table #RecoveryAccountCaseNotes
(
	LegacyAccountNumberIdentifier	varchar(11),
	NoteDescription					varchar(max),
	DateNoteEntered					datetime
 )

select @record_length = case_notes_length,
	@delete_special_chars_file7 = delete_special_chars_file7,
	@alerts_file7 = alerts_file7
from CalSAWSSettings

/* Get full Activity memos */
insert #RecoveryAccountCaseNotes
select "Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,
 	"Note Description" = dbo.CleanMemoFunction(activity_code + 
				IsNull((select ' - ' + description from activity where activity_code = user_activity.activity_code), '') + 
 				IsNull((select ' - ' + logon_id from users where user_number = user_activity.user_number), '') + 
				IsNull( ' - ' + memo, '- No Memo Entered') + 
				IsNull(convert(varchar(max), memo_text), '')),
	"Date Note Entered" = date_of_activity
			
from debt

JOIN debt_user_activity ON debt.debt_number = debt_user_activity.debt_number
JOIN user_activity ON debt_user_activity.activity_number = user_activity.activity_number
JOIN DebtList ON DebtList.debt_number = debt.debt_number
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number
 
where memo is not null


if @alerts_file7 = 'Y'
Begin
/* Get Alerts */
	insert #RecoveryAccountCaseNotes
	select "Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,
 		"Note Description" = 'Alert - ' + dbo.CleanMemoFunction(user_login + 
				IsNull( ' - ' + memo1, '- No Alert Entered') + 
				IsNull(memo2, '')),
		"Date Note Entered" = alerts.date_entered
			
	from debt

	JOIN alerts ON debt.debtor_id = alerts.debtor_id
	JOIN DebtList ON DebtList.debt_number = debt.debt_number
	JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number
 
	where memo1 is not null
End /* Get Alerts */


if @delete_special_chars_file7 = 'Y'
/* Delete all non-ascii characters */
	update #RecoveryAccountCaseNotes
	set NoteDescription =  dbo.RemoveNonASCII(NoteDescription)

             
delete RecoveryAccountCaseNotes

insert RecoveryAccountCaseNotes
select LegacyAccountNumberIdentifier,
	substring(NoteDescription, 1, @record_length),
	DateNoteEntered
from #RecoveryAccountCaseNotes


select @max_memo_length = max(datalength(NoteDescription))
from #RecoveryAccountCaseNotes

select @memo_count = CEILING(@max_memo_length/@record_length)

select @index = 1

while @memo_count > @index
begin
	insert RecoveryAccountCaseNotes
	select LegacyAccountNumberIdentifier,
		substring(NoteDescription, (@index * @record_length) + 1, @record_length),
		DATEADD(second, @index, DateNoteEntered)
	from #RecoveryAccountCaseNotes
	where datalength(NoteDescription) > @index * @record_length

	select @index = @index + 1

end

/* Note describing Aid Types that are unknown in CalSAWS */
insert RecoveryAccountCaseNotes
select "Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,
 	"Note Description" = 'Aid Code: ' + AidCode + IsNull(' - ' + calsaws_description, ''),
	"Date Note Entered" = getdate()
			
from RecoveryAccountOverpayment

JOIN CalSAWSAidCodeMap ON RecoveryAccountOverpayment.AidCode = CalSAWSAidCodeMap.vacs_code
Where IsNull(CalSAWSAidCodeMap.calsaws_code, '') = ''

go

grant execute on FillRecoveryAccountCaseNotes to public
go

/*   	
	procedure:	FillRecoveryAccountProviders.prc
	written by:    	Craig Deane
     	date written:  	June 2021
     	database:      	welcoll
     	function:      	This fills the RecoveryAccountProviders table with debtor data
    	modified by:   	Craig Deane 9/30/2021 Version 2.0
     	changes: 	Changed processing for the Organization ID
   	modified by:   	Craig Deane Version 10/21/2021 2.0.1
     	changes: 	Set ax Type Code to 'IC'. Changed the processing for Organization ID
   	modified by:   	Craig Deane 1/11/2022 Version 2.1
     	changes: 	Changed the Where clause to make it explicit that only individuals can produce this record
*/

use welcoll
go

IF EXISTS(SELECT 1
          FROM   INFORMATION_SCHEMA.ROUTINES
          WHERE  ROUTINE_NAME = 'FillRecoveryAccountProviders'
                 AND SPECIFIC_SCHEMA = 'dbo')
  BEGIN
      DROP PROCEDURE dbo.FillRecoveryAccountProviders
  END
go

create procedure dbo.FillRecoveryAccountProviders
as

delete RecoveryAccountProviders

insert RecoveryAccountProviders
select 	"Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,

	"Organization ID" = '1' + Replicate('0', 8 - Len(Convert(varchar(9), debtor.debtor_id))) + Convert(varchar(9), debtor.debtor_id),

	"Organization Name" = debtor1_name_first + ' ' +  debtor1_name_mid_init + ' ' + (select last_name from dbo.NameSuffixFunction(debtor1_name_last)) + ' ' + (select suffix_name from dbo.NameSuffixFunction(debtor1_name_last)),

	"Tax Type Code"	= 'IC',

	"Tax ID Type" = 'SN',

	"Tax ID" = debtor1_ssn,

	"Physical Address - Line 1 Address" = '',

	"Physical  Address - Line 2 Address" = '',

	"Physical  Address - City Name" = '',

	"Physical  Address- State Code" = '',

	"Physical  Address - Zip Code" = '',

	"Mailing Address- Line 1 Address" = Case When IsNull(debtor1_street_address, '') <> '' Then (select address_line1 from AddressFunction(debtor1_street_address)) Else
						Case When IsNull(debtor1_private_mailbox, '') <> '' Then debtor1_private_mailbox Else
							Case When IsNull(debtor1_care_of_address, '') <> '' Then debtor1_care_of_address End 
						End 
					    End,

	"Mailing Address- Line 2 Address" = Case When IsNull(debtor1_street_address, '') <> '' Then (select address_line2 from AddressFunction(debtor1_street_address)) End,

	"Mailing Address - City Name" = debtor1_city,

	"Mailing Address- State Code" = debtor1_state,

	"Mailing Address - Zip Code" =  debtor1_zip,

	"Phone Number - Area Code" = substring(debtor1_phone, 1, 3),

	"Phone Number" = substring(debtor1_phone, 4, 7),

	"Phone Extension Number" = ''

from debt
INNER JOIN debtor ON debt.debtor_id = debtor.debtor_id
INNER JOIN DebtList ON debt.debt_number = DebtList.debt_number
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number
where file8_process_indicator = 'Y'

update RecoveryAccountProviders
set PhysicalAddressLine1Address = MailingAddressLine1Address,
PhysicalAddressLine2Address = MailingAddressLine2Address,
PhysicalAddressCityName = MailingAddressCityName,
PhysicalAddressStateCode = MailingAddressStateCode,
PhysicalAddressZipCode = MailingAddressZipCode
            
go

grant execute on FillRecoveryAccountProviders to public
go

/*	
	procedure:	CreateDebtList.prc
	written by:    	Craig Deane
	date written:  	2/3/2021
	database:      	welcoll
	function:     	Generates the list of debts to be extracted
	modified by:   	Craig Deane 2/9/2021
	changes:	Modified to use the CalSAWSSettings table	
	modified by:   	Craig Deane 5/24/2021
	changes:	Added filters for exclude_non_bic_ind, exclude_indicator, and exclude_zero_balance_indicator. Fixed a bug in the percentage proceesing 	
	modified by:   	Craig Deane 6/10/2021	FSD 1.7
	changes:	Added options for the date cutoff: Date Debt Status, Date of Discovery, and Date Entered
   	modified by:   	Craig Deane 1/11/2022 Version 2.1
     	changes:	Added the Golive Date to be used for subtracting the Date Cutoff when not null. Added an indicator for the File #8 process
*/

use welcoll
go

IF EXISTS(SELECT 1
          FROM   INFORMATION_SCHEMA.ROUTINES
          WHERE  ROUTINE_NAME = 'CreateDebtList'
                 AND SPECIFIC_SCHEMA = 'dbo')
  BEGIN
      DROP PROCEDURE dbo.CreateDebtList
  END
go

create procedure dbo.CreateDebtList
as

declare @percentage 		dec(5, 2),
	@years			integer,
	@months			integer,
	@days			integer,
	@date_cutoff		datetime,
	@date_cutoff_ind	integer,
	@other_reason_text_ind	char(1),
	@exclude_non_bic_ind	char(1),
	@cutoff_date_field_ind	integer,
	@cutoff_date_field	datetime,
	@golive_date		datetime

select @percentage = data_set_percentage,
	@years = date_cutoff_years,
	@months = date_cutoff_months,
	@days = date_cutoff_days,
	@other_reason_text_ind = other_reason_text_ind,	
	@exclude_non_bic_ind = exclude_non_bic_ind,
	@cutoff_date_field_ind = cutoff_date_field_ind,
	@golive_date = golive_date
from CalSAWSSettings 
where key_value = 1


if IsNull(@percentage, 100) < 1 
	select @percentage = 1

if IsNull(@percentage, 100) > 100
	select @percentage = 100

select @percentage = 100 / @percentage

select @date_cutoff_ind = IsNull(@years, 0) + IsNull(@months, 0) + IsNull(@days, 0)

if @date_cutoff_ind > 0
begin
  select @date_cutoff = DATEADD(Year, - IsNull(@years, 0), IsNull(@golive_date, GETDATE())) 
  select @date_cutoff = DATEADD(Month, - IsNull(@months, 0), @date_cutoff) 
  select @date_cutoff = DATEADD(Day, - IsNull(@days, 0), @date_cutoff) 
end

delete DebtList

insert DebtList
  select debt_number, 'N'
  from debt
  where floor(debt_number % @percentage) = 0

delete DebtList
from debt
where DebtList.debt_number = debt.debt_number and
	balance_amount = 0 and 
	(date_debt_status < @date_cutoff and @cutoff_date_field_ind = 0 or
	 date_of_discovery < @date_cutoff and @cutoff_date_field_ind = 1 or
	 date_entered < @date_cutoff and @cutoff_date_field_ind = 2) and
	(IsNull(other_reason_text, '') = '' or @other_reason_text_ind = 'N') and
	@date_cutoff_ind > 0

delete DebtList
from debt
where DebtList.debt_number = debt.debt_number and
	balance_amount < 0 

delete DebtList
from debt
where DebtList.debt_number = debt.debt_number and
		type_code in (select vacs_code
			from CalSAWSProgramCodeMap
			where exclude_indicator = 1)

delete DebtList
from debt
where DebtList.debt_number = debt.debt_number and
		debt_status in (select vacs_code
			from CalSAWSRecoveryAccountStatusMap
			where exclude_zero_balance_indicator = 1)

delete DebtList
from debt
where DebtList.debt_number = debt.debt_number and
	IsNull(bic_code, '') = '' and
	@exclude_non_bic_ind = 'Y'


update DebtList
set file8_process_indicator = 'Y'
from debt
INNER JOIN debtor ON debt.debtor_id = debtor.debtor_id
INNER JOIN DebtList ON debt.debt_number = DebtList.debt_number
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number
where type_code in ('FOS', 'IHS', 'AAP') and
	IsNull(provider_number, '') = '' and
	IsNull(cin1, '') = '' and
	IsNull(cin2, '') = '' and
	IsNull(debtor1_name_mid_init, '') <> '*'

go

grant execute on CreateDebtList to public
go

/*   procedure:     PriorityNumbers.prc
     written by:    Craig Deane
     date written:  10/7/2020
     database:      welcoll
     function:      Generates the Priority Numbers for the Recovery Account
     modified by:  
     changes: 	 
*/

use welcoll
go

IF EXISTS(SELECT 1
          FROM   INFORMATION_SCHEMA.ROUTINES
          WHERE  ROUTINE_NAME = 'PriorityNumbers'
                 AND SPECIFIC_SCHEMA = 'dbo')
  BEGIN
      DROP PROCEDURE dbo.PriorityNumbers
  END
go

create procedure dbo.PriorityNumbers
as

declare @priority_number	integer,
	@serial_number		char(9),
	@debt_number		integer,
	@temp_serial_number	char(9)

delete PriorityNumber

DECLARE priority_numbers CURSOR
    FOR select serial_number,
		debt.debt_number
	from debt, DebtList
	where debt.debt_number = DebtList.debt_number
	order by serial_number, debt_type_code desc, date_entered

OPEN priority_numbers

select @priority_number = 0

FETCH NEXT FROM priority_numbers INTO @serial_number, @debt_number

select @temp_serial_number = @serial_number

WHILE @@FETCH_STATUS = 0  
    BEGIN
	if @serial_number = @temp_serial_number
	begin
	   select @priority_number = @priority_number + 1
	end
	else
	begin
	    select @priority_number = 1
	    select @temp_serial_number = @serial_number
	end

	insert PriorityNumber
	select @priority_number, @serial_number, @debt_number

        FETCH NEXT FROM priority_numbers INTO @serial_number, @debt_number

	

    END


CLOSE priority_numbers

DEALLOCATE priority_numbers

go

grant execute on PriorityNumbers to public
go

